@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2021 the xine project
+ * Copyright (C) 2000-2007 the xine project
  *
  * This file is part of xine, a unix video player.
  *
@@ -26,7 +26,6 @@
  * @author James Courtier-Dutton (2001-12-09)
  */
 
-#define _DEFAULT_SOURCE 1
 #ifndef __sun
 /* required for swab() */
 #define _XOPEN_SOURCE 500
@@ -42,6 +41,9 @@
 #include <unistd.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <assert.h>
 
 #define LOG_MODULE "libdts"
 #define LOG_VERBOSE
@@ -60,10 +62,15 @@
 
 #define MAX_AC5_FRAME 4096
 
+typedef struct {
+  audio_decoder_class_t   decoder_class;
+} dts_class_t;
+
 typedef struct {
   audio_decoder_t  audio_decoder;
 
   xine_stream_t    *stream;
+  audio_decoder_class_t *class;
 
   dts_state_t     *dts_state;
   int64_t          pts;
@@ -72,7 +79,7 @@ typedef struct {
   int              sync_state;
   int              ac5_length, ac5_pcm_length, frame_todo;
   uint32_t         syncdword;
-  uint8_t          frame_buffer[MAX_AC5_FRAME + 1];
+  uint8_t          frame_buffer[MAX_AC5_FRAME];
   uint8_t         *frame_ptr;
 
   int              output_open;
@@ -89,11 +96,9 @@ typedef struct {
 } dts_decoder_t;
 
 static void dts_reset (audio_decoder_t *const this_gen) {
-  (void)this_gen;
 }
 
 static void dts_discontinuity (audio_decoder_t *const this_gen) {
-  (void)this_gen;
 }
 
 /**
@@ -155,11 +160,9 @@ static void dts_decode_frame (dts_decoder_t *this, const int64_t pts) {
         return;
 
       data_out=(uint8_t *) audio_buffer->mem;
-      if (this->ac5_length > MAX_AC5_FRAME) {
-        /* XXX is this even possible ? ac5_length is checked in dts_decode_data() */
+      if (this->ac5_length > 8191) {
         xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG, "libdts: ac5_length too long\n");
         this->ac5_pcm_length = 0;
-        return;
       }
 
       switch (this->ac5_pcm_length) {
@@ -325,7 +328,7 @@ static void dts_decode_frame (dts_decoder_t *this, const int64_t pts) {
 
 static void dts_decode_data (audio_decoder_t *this_gen, buf_element_t *buf) {
 
-  dts_decoder_t  *const this = xine_container_of(this_gen, dts_decoder_t, audio_decoder);
+  dts_decoder_t  *const this = (dts_decoder_t *) this_gen;
   uint8_t        *current = (uint8_t *)buf->content;
   uint8_t        *sync_start=current + 1;
   uint8_t        *const end = buf->content + buf->size;
@@ -432,18 +435,16 @@ static void dts_decode_data (audio_decoder_t *this_gen, buf_element_t *buf) {
     case 2:  /* Filling frame_buffer with sync_info bytes */
 	  *this->frame_ptr++ = *current++;
 	  this->frame_todo--;
-          if (this->frame_todo > 0) {
-            break;
-          }
-          this->sync_state = 3;
-          /* fall through */
+	  if (this->frame_todo < 1) {
+	    this->sync_state = 3;
+          } else break;
+
     case 3:  /* Ready for decode */
 #if 0
           dtsdec_decode_frame (this, this->pts_list[0]);
 #else
           dts_decode_frame (this, this->pts);
 #endif
-          /* fall through */
     case 4:  /* Clear up ready for next frame */
           this->pts = 0;
 	  this->syncdword = 0;
@@ -456,26 +457,20 @@ static void dts_decode_data (audio_decoder_t *this_gen, buf_element_t *buf) {
 }
 
 static void dts_dispose (audio_decoder_t *this_gen) {
-  dts_decoder_t *const this = xine_container_of(this_gen, dts_decoder_t, audio_decoder);
+  dts_decoder_t *const this = (dts_decoder_t *) this_gen;
 
   if (this->output_open)
     this->stream->audio_out->close (this->stream->audio_out, this->stream);
 
-  dca_free(this->dts_state);
-  this->dts_state = NULL;
   free (this);
 }
 
 static audio_decoder_t *open_plugin (audio_decoder_class_t *class_gen, xine_stream_t *stream) {
   dts_decoder_t *this ;
 
-  (void)class_gen;
-
   lprintf("open_plugin\n");
 
   this = calloc(1, sizeof (dts_decoder_t));
-  if (!this)
-    return NULL;
 
   this->audio_decoder.decode_data         = dts_decode_data;
   this->audio_decoder.reset               = dts_reset;
@@ -558,22 +553,25 @@ static audio_decoder_t *open_plugin (audio_decoder_class_t *class_gen, xine_stre
     }
   }
   this->stream        = stream;
+  this->class         = class_gen;
   this->output_open   = 0;
 
   return &this->audio_decoder;
 }
 
-static void *init_plugin (xine_t *xine, const void *data) {
+static void *init_plugin (xine_t *xine, void *data) {
+  dts_class_t *this ;
 
-  static const audio_decoder_class_t this = {
-    .open_plugin     = open_plugin,
-    .identifier      = "DTS",
-    .description     = N_("DTS passthru audio format decoder plugin"),
-    .dispose         = NULL
-  };
-  (void)xine;
-  (void)data;
-  return (void *)&this;
+  lprintf("init_plugin\n");
+
+  this = calloc(1, sizeof (dts_class_t));
+
+  this->decoder_class.open_plugin     = open_plugin;
+  this->decoder_class.identifier      = "DTS";
+  this->decoder_class.description     = N_("DTS passthru audio format decoder plugin");
+  this->decoder_class.dispose         = default_audio_decoder_class_dispose;
+
+  return this;
 }
 
 static const uint32_t audio_types[] = {
@@ -581,12 +579,12 @@ static const uint32_t audio_types[] = {
  };
 
 static const decoder_info_t dec_info_audio = {
-  .supported_types = audio_types,
-  .priority        = 8,
+  audio_types,         /* supported types */
+  1                    /* priority        */
 };
 
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_AUDIO_DECODER, 16, "dts", XINE_VERSION_CODE, &dec_info_audio, init_plugin },
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
