@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2016 the xine project
+ * Copyright (C) 2000-2004 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -39,8 +39,6 @@
 #define LOG
 */
 
-#include "group_video.h"
-
 #include <xine/xine_internal.h>
 #include <xine/demux.h>
 #include <xine/xineutils.h>
@@ -808,8 +806,7 @@ static uint32_t parse_pack(demux_mpeg_t *this) {
        lprintf ("mux_rate = %d\n",this->rate);
 
      } else
-       /* skip rate */
-       read_bytes (this, 3) ;
+       buf = read_bytes (this, 3) ;
   }
 
   /* system header */
@@ -855,7 +852,7 @@ static uint32_t parse_pack_preview (demux_mpeg_t *this, int *num_buffers) {
   buf = read_bytes (this, 1);
 
   if ((buf>>6) == 0x01) {
-     read_bytes(this, 1); /* skip byte */
+     buf = read_bytes(this, 1);
      mpeg_version = 2;
   } else {
      mpeg_version = 1;
@@ -884,8 +881,7 @@ static uint32_t parse_pack_preview (demux_mpeg_t *this, int *num_buffers) {
     /* lprintf("mux_rate = %d\n",this->rate); */
 
   } else
-    /* skip rate */
-    read_bytes (this, 3) ;
+    buf = read_bytes (this, 3) ;
 
   if( mpeg_version == 2 )
   {
@@ -1225,7 +1221,7 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
   return &this->demux_plugin;
 }
 
-void *demux_mpeg_init_class (xine_t *xine, void *data) {
+static void *init_plugin (xine_t *xine, void *data) {
   demux_mpeg_class_t     *this;
 
   this = calloc(1, sizeof(demux_mpeg_class_t));
@@ -1242,3 +1238,15 @@ void *demux_mpeg_init_class (xine_t *xine, void *data) {
   return this;
 }
 
+/*
+ * exported plugin catalog entry
+ */
+static const demuxer_info_t demux_info_mpeg = {
+  9                        /* priority */
+};
+
+const plugin_info_t xine_plugin_info[] EXPORTED = {
+  /* type, API, "name", version, special_info, init_function */
+  { PLUGIN_DEMUX, 27, "mpeg", XINE_VERSION_CODE, &demux_info_mpeg, init_plugin },
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
+};
