@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2017 the xine project,
+ * Copyright (C) 2000-2005 the xine project,
  *                         Rich Wareham <richwareham@users.sourceforge.net>
  *
  * This file is part of xine, a free video player.
@@ -46,7 +46,6 @@
 #include <sys/stat.h>
 
 #include <unistd.h>
-#include <pthread.h>
 #include <fcntl.h>
 #include <time.h>
 #include <string.h>
@@ -89,16 +88,10 @@
 #  endif
 #else
 #  define DVDNAV_COMPILE
-#  include "libdvdnav/dvdnav.h"
-#  include "libdvdnav/nav_read.h"
+#  include "dvdnav.h"
+#  include "nav_read.h"
 #endif
 
-#define LOG_MODULE "input_http"
-#define LOG_VERBOSE
-/*
-#define LOG
-*/
-
 /* Xine includes */
 #include <xine/xineutils.h>
 #include <xine/buffer.h>
@@ -108,6 +101,12 @@
 /* Print debug messages? */
 /* #define INPUT_DEBUG */
 
+/* Print trace messages? */
+/* #define INPUT_DEBUG_TRACE */
+
+/* Print debug of eject */
+/* #define LOG_DVD_EJECT */
+
 /* Current play mode (title only or menus?) */
 #define MODE_FAIL	0
 #define MODE_NAVIGATE	1
@@ -139,6 +138,25 @@
 #  define DVD_BLOCK_SIZE 2048
 #endif
 
+/* Debugging macros */
+#ifdef __GNUC__
+# ifdef INPUT_DEBUG_TRACE
+#  define trace_print(s, args...) printf("input_dvd: %s : " s, __FUNCTION__, ##args);
+# else
+#  define trace_print(s, args...) /* Nothing */
+# endif
+#else
+#  ifndef _MSC_VER
+#    define trace_print(s, ...) /* Nothing */
+#  else
+#    ifdef INPUT_DEBUG_TRACE
+#      define trace_print printf
+#    else
+#      define trace_print() /* Nothing */
+#    endif /* INPUT_DEBUG_TRACE */
+#  endif /* _MSC_VER */
+#endif
+
 #if defined (__FreeBSD__)
 # define off64_t off_t
 # define lseek64 lseek
@@ -229,7 +247,7 @@ static void device_change_cb(void *data, xine_cfg_entry_t *cfg) {
 static uint32_t dvd_plugin_get_capabilities (input_plugin_t *this_gen) {
   dvd_input_plugin_t *this = (dvd_input_plugin_t*)this_gen;
 
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   return INPUT_CAP_BLOCK |
   /* TODO: figure out if there is any "allow copying" flag on DVD.
@@ -348,6 +366,9 @@ static int update_title_display(dvd_input_plugin_t *this) {
   int tt=-1, pr=-1;
   int num_tt = 0;
 
+  if(!this || !(this->stream))
+   return 0;
+
   /* Set title/chapter display */
 
   dvdnav_current_title_info(this->dvdnav, &tt, &pr);
@@ -425,7 +446,7 @@ static int update_title_display(dvd_input_plugin_t *this) {
 static void dvd_plugin_dispose (input_plugin_t *this_gen) {
   dvd_input_plugin_t *this = (dvd_input_plugin_t*)this_gen;
 
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   if (this->event_queue)
     xine_event_dispose_queue (this->event_queue);
@@ -548,8 +569,8 @@ static void dvd_plugin_free_buffer(buf_element_t *buf) {
   if (this->freeing && !this->mem_stack) {
     /* all buffers returned, we can free the plugin now */
     pthread_mutex_destroy(&this->buf_mutex);
-    _x_freep(&this->mem);
-    _x_freep(&this->mrl);
+    free(this->mem);
+    free(this->mrl);
     free(this);
   }
 }
@@ -851,7 +872,7 @@ static off_t dvd_plugin_get_current_pos (input_plugin_t *this_gen){
   uint32_t pos=0;
   uint32_t length=1;
   /*dvdnav_status_t result;*/
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   if(!this || !this->dvdnav) {
     return 0;
@@ -863,7 +884,7 @@ static off_t dvd_plugin_get_current_pos (input_plugin_t *this_gen){
 static off_t dvd_plugin_seek (input_plugin_t *this_gen, off_t offset, int origin) {
   dvd_input_plugin_t *this = (dvd_input_plugin_t*)this_gen;
 
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   if(!this || !this->dvdnav) {
     return -1;
@@ -876,7 +897,7 @@ static off_t dvd_plugin_seek (input_plugin_t *this_gen, off_t offset, int origin
 static off_t dvd_plugin_seek_time (input_plugin_t *this_gen, int time_offset, int origin) {
   dvd_input_plugin_t *this = (dvd_input_plugin_t*)this_gen;
 
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   if(!this || !this->dvdnav || origin != SEEK_SET) {
     return -1;
@@ -893,7 +914,7 @@ static off_t dvd_plugin_get_length (input_plugin_t *this_gen) {
   uint32_t length=1;
   /*dvdnav_status_t result;*/
 
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   if(!this || !this->dvdnav) {
     return 0;
@@ -903,7 +924,7 @@ static off_t dvd_plugin_get_length (input_plugin_t *this_gen) {
 }
 
 static uint32_t dvd_plugin_get_blocksize (input_plugin_t *this_gen) {
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   return DVD_BLOCK_SIZE;
 }
@@ -911,7 +932,7 @@ static uint32_t dvd_plugin_get_blocksize (input_plugin_t *this_gen) {
 static const char* dvd_plugin_get_mrl (input_plugin_t *this_gen) {
   dvd_input_plugin_t *this = (dvd_input_plugin_t*)this_gen;
 
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   return this->mrl;
 }
@@ -1380,16 +1401,14 @@ static int dvd_parse_try_open(dvd_input_plugin_t *this, const char *locator)
     /* we have an alternative dvd_path */
     intended_dvd_device = locator;
     /* do not use the raw device for the alternative */
-    /*xine_setenv("DVDCSS_RAW_DEVICE", "", 1);*/
+    xine_setenv("DVDCSS_RAW_DEVICE", "", 1);
   } else {
     /* use default DVD device */
     dvd_input_class_t *class = (dvd_input_class_t*)this->input_plugin.input_class;
-    /*
     xine_cfg_entry_t raw_device;
     if (xine_config_lookup_entry(this->stream->xine,
 	"media.dvd.raw_device", &raw_device))
       xine_setenv("DVDCSS_RAW_DEVICE", raw_device.str_value, 1);
-    */
     intended_dvd_device = class->dvd_device;
   }
 
@@ -1462,7 +1481,7 @@ static int dvd_plugin_open (input_plugin_t *this_gen) {
   char                  *title_part;
   xine_cfg_entry_t       region_entry, lang_entry, cfg_entry;
 
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   /* we already checked the "dvd:/" MRL before */
   locator_orig = locator = strdup (this->mrl + (sizeof("dvd:") - 1));
@@ -1605,7 +1624,7 @@ static input_plugin_t *dvd_class_get_instance (input_class_t *class_gen, xine_st
   dvd_input_class_t     *class = (dvd_input_class_t*)class_gen;
   static const char handled_mrl[] = "dvd:/";
 
-  lprintf("Called\n");
+  trace_print("Called\n");
 
   /* Check we can handle this MRL */
   if (strncasecmp (data, handled_mrl, sizeof(handled_mrl)-1 ) != 0)
@@ -1671,7 +1690,7 @@ static xine_mrl_t **dvd_class_get_dir (input_class_t *this_gen,
 						       const char *filename, int *nFiles) {
   dvd_input_class_t *this = (dvd_input_class_t*)this_gen;
 
-  lprintf("Called\n");
+  trace_print("Called\n");
   if (filename) { *nFiles = 0; return NULL; }
 
 /*
@@ -1689,7 +1708,7 @@ static const char * const *dvd_class_get_autoplay_list (input_class_t *this_gen,
 
   static const char * const filelist[] = {"dvd:/", NULL};
 
-  lprintf("get_autoplay_list entered\n");
+  trace_print("get_autoplay_list entered\n");
 
   *num_files = 1;
 
@@ -1707,7 +1726,7 @@ static void dvd_class_dispose(input_class_t *this_gen) {
   config->unregister_callback(config, "media.dvd.seek_behaviour");
   config->unregister_callback(config, "media.dvd.play_single_chapter");
 
-  _x_freep(&this->eject_device);
+  free(this->eject_device);
   free(this);
 }
 
@@ -1725,7 +1744,7 @@ static void *init_class (xine_t *xine, void *data) {
   static const char *const seek_modes[] = {"seek in program chain", "seek in program", NULL};
   static const char *const play_single_chapter_modes[] = {"entire dvd", "one chapter", NULL};
 
-  lprintf("Called\n");
+  trace_print("Called\n");
 #ifdef INPUT_DEBUG
   printf("input_dvd.c: init_class called.\n");
   printf("input_dvd.c: config = %p\n", config);
@@ -1766,11 +1785,10 @@ static void *init_class (xine_t *xine, void *data) {
 #endif
   {
     /* we have found libdvdcss, enable the specific config options */
-    /* char *raw_device; */
+    char *raw_device;
     static const char *const decrypt_modes[] = { "key", "disc", "title", NULL };
     int mode;
 
-    /*
     raw_device = config->register_filename(config, "media.dvd.raw_device",
 					 RDVD_PATH, XINE_CONFIG_STRING_IS_DEVICE_NAME,
 					 _("raw device set up for DVD access"),
@@ -1785,10 +1803,9 @@ static void *init_class (xine_t *xine, void *data) {
 					   "(man raw) for further information."),
 					 10, NULL, NULL);
     if (raw_device) xine_setenv("DVDCSS_RAW_DEVICE", raw_device, 0);
-    */
 
     mode = config->register_enum(config, "media.dvd.css_decryption_method", 0,
-				 (char **)decrypt_modes, _("CSS decryption method"),
+				 decrypt_modes, _("CSS decryption method"),
 				 _("Selects the decryption method libdvdcss will use to descramble "
 				   "copy protected DVDs. Try the various methods, if you have problems "
 				   "playing scrambled DVDs."), 20, NULL, NULL);
@@ -1824,7 +1841,7 @@ static void *init_class (xine_t *xine, void *data) {
 			  "of the DVD layer change on faster drives."),
 			10, read_ahead_cb, this);
   config->register_enum(config, "media.dvd.skip_behaviour", 0,
-			(char **)skip_modes,
+			skip_modes,
 			_("unit for the skip action"),
 			_("You can configure the behaviour when issuing a skip command (using the skip "
 			  "buttons for example). The individual values mean:\n\n"
@@ -1840,7 +1857,7 @@ static void *init_class (xine_t *xine, void *data) {
 			  "features on the DVD"),
 			20, NULL, NULL);
   config->register_enum(config, "media.dvd.seek_behaviour", 0,
-			(char **)seek_modes,
+			seek_modes,
 			_("unit for seeking"),
 			_("You can configure the domain spanned by the seek slider. The individual "
 			  "values mean:\n\n"
@@ -1852,7 +1869,7 @@ static void *init_class (xine_t *xine, void *data) {
 			  "a chapter of the current feature"),
 			20, seek_mode_cb, this);
   config->register_enum(config, "media.dvd.play_single_chapter", 0,
-			(char **)play_single_chapter_modes,
+			play_single_chapter_modes,
 			_("play mode when title/chapter is given"),
 			_("You can configure the behaviour when playing a dvd from a given "
 			  "title/chapter (eg. using MRL 'dvd:/1.2'). The individual values mean:\n\n"
