@@ -1,7 +1,7 @@
 /*
  * kate: space-indent on; indent-width 2; mixedindent off; indent-mode cstyle; remove-trailing-space on;
  *
- * Copyright (C) 2010-2021 the xine project
+ * Copyright (C) 2010 the xine project
  * Copyright (C) 2010 Christophe Thommeret <hftom@free.fr>
  *
  * This file is part of xine, a free video player.
@@ -44,7 +44,6 @@
 #include <xine/xineutils.h>
 #include "accel_vdpau.h"
 #include "bits_reader.h"
-#include "group_vdpau.h"
 
 #include <vdpau/vdpau.h>
 
@@ -179,6 +178,8 @@ typedef struct {
 
   vdpau_accel_t *accel_vdpau;
 
+  VdpColorStandard  color_standard;
+
   bits_reader_t  br;
 
   int         vdp_runtime_nr;
@@ -195,14 +196,20 @@ typedef struct {
   int         last_non_b_time;
   int         t_frame;
 
-  int         color_matrix;
-
 } sequence_t;
 
 
+
+typedef struct {
+  video_decoder_class_t   decoder_class;
+} vdpau_mpeg4_class_t;
+
+
+
 typedef struct vdpau_mpeg4_decoder_s {
   video_decoder_t         video_decoder;  /* parent video decoder structure */
 
+  vdpau_mpeg4_class_t    *class;
   xine_stream_t           *stream;
 
   sequence_t              sequence;
@@ -273,6 +280,7 @@ static void reset_sequence( sequence_t *sequence, int free_refs )
   sequence->backward_ref = NULL;
   sequence->top_field_first = 0;
   sequence->reset = VO_NEW_SEQUENCE_FLAG;
+  sequence->color_standard = VDP_COLOR_STANDARD_ITUR_BT_709;
 
   sequence->last_time_base = 0;
   sequence->time_base = 0;
@@ -324,7 +332,6 @@ static void visual_object( vdpau_mpeg4_decoder_t *this_gen, uint8_t *buf, int le
 {
   sequence_t *sequence = (sequence_t*)&this_gen->sequence;
   picture_t *picture = (picture_t*)&sequence->picture;
-  int xine_color_matrix = 4; /* undefined, mpeg range */
   bits_reader_set( &sequence->br, buf, len );
 
   if ( read_bits( &sequence->br, 1 ) ) {
@@ -334,16 +341,16 @@ static void visual_object( vdpau_mpeg4_decoder_t *this_gen, uint8_t *buf, int le
   }
   if ( read_bits( &sequence->br, 4 ) == 1 ) {
     if ( read_bits( &sequence->br, 1 ) ) {
-      skip_bits (&sequence->br, 3); /* video_format */
-      xine_color_matrix |= read_bits (&sequence->br, 1); /* full range */
+      skip_bits( &sequence->br, 4 );
       if ( read_bits( &sequence->br, 1 ) ) {
-        skip_bits (&sequence->br, 16);
-        xine_color_matrix = (xine_color_matrix & 1)
-          | (read_bits (&sequence->br, 8) << 1);  /* matrix_coefficients */
+        if ( read_bits( &sequence->br, 8 ) == 7 ) {
+          lprintf("color_standard: smpte_240M\n");
+          sequence->color_standard = VDP_COLOR_STANDARD_SMPTE_240M;
+        }
+        skip_bits( &sequence->br, 16 );
       }
     }
   }
-  VO_SET_FLAGS_CM (xine_color_matrix, sequence->color_matrix);
 }
 
 
@@ -763,7 +770,7 @@ static int parse_code( vdpau_mpeg4_decoder_t *this_gen, uint8_t *buf, int len )
 {
   sequence_t *sequence = (sequence_t*)&this_gen->sequence;
 
-  if ( /* (buf[3] >= begin_vo_start_code) ">= 0" && */ (buf[3] <= end_vo_start_code) ) {
+  if ( (buf[3] >= begin_vo_start_code) && (buf[3] <= end_vo_start_code) ) {
     lprintf( " ----------- vo_start_code\n" );
     return 0;
   }
@@ -817,15 +824,11 @@ static void decode_render( vdpau_mpeg4_decoder_t *vd, vdpau_accel_t *accel, uint
 
   VdpStatus st;
   if ( vd->decoder==VDP_INVALID_HANDLE || vd->decoder_profile!=seq->profile || vd->decoder_width!=seq->coded_width || vd->decoder_height!=seq->coded_height ) {
-    if (accel->lock)
-      accel->lock (accel->vo_frame);
     if ( vd->decoder!=VDP_INVALID_HANDLE ) {
       accel->vdp_decoder_destroy( vd->decoder );
       vd->decoder = VDP_INVALID_HANDLE;
     }
     st = accel->vdp_decoder_create( accel->vdp_device, seq->profile, seq->coded_width, seq->coded_height, 2, &vd->decoder);
-    if (accel->unlock)
-      accel->unlock (accel->vo_frame);
     if ( st!=VDP_STATUS_OK )
       fprintf(stderr, "vdpau_mpeg4: failed to create decoder !! %s\n", accel->vdp_get_error_string( st ) );
     else {
@@ -844,15 +847,11 @@ static void decode_render( vdpau_mpeg4_decoder_t *vd, vdpau_accel_t *accel, uint
   vbit.struct_version = VDP_BITSTREAM_BUFFER_VERSION;
   vbit.bitstream = buf;
   vbit.bitstream_bytes = len;
-  if (accel->lock)
-    accel->lock (accel->vo_frame);
-  st = accel->vdp_decoder_render( vd->decoder, accel->surface, CAST_VdpPictureInfo_PTR &pic->vdp_infos, 1, &vbit );
-  if (accel->unlock)
-    accel->unlock (accel->vo_frame);
+  st = accel->vdp_decoder_render( vd->decoder, accel->surface, (VdpPictureInfo*)&pic->vdp_infos, 1, &vbit );
   if ( st!=VDP_STATUS_OK )
     fprintf(stderr, "vdpau_mpeg4: decoder failed : %d!! %s\n", st, accel->vdp_get_error_string( st ) );
   else {
-    lprintf( "DECODER SUCCESS : vop_coding_type=%d, bytes=%d, current=%d, forwref:%d, backref:%d, pts:%" PRId64 "\n",
+    lprintf( "DECODER SUCCESS : vop_coding_type=%d, bytes=%d, current=%d, forwref:%d, backref:%d, pts:%lld\n",
               pic->vdp_infos.vop_coding_type, vbit.bitstream_bytes, accel->surface, pic->vdp_infos.forward_reference, pic->vdp_infos.backward_reference, seq->seq_pts );
   }
 }
@@ -900,7 +899,7 @@ static void decode_picture( vdpau_mpeg4_decoder_t *vd )
     }
   }
 
-  vo_frame_t *img = vd->stream->video_out->get_frame( vd->stream->video_out, seq->coded_width, seq->coded_height, seq->ratio, XINE_IMGFMT_VDPAU, VO_BOTH_FIELDS | seq->color_matrix );
+  vo_frame_t *img = vd->stream->video_out->get_frame( vd->stream->video_out, seq->coded_width, seq->coded_height, seq->ratio, XINE_IMGFMT_VDPAU, VO_BOTH_FIELDS );
   vdpau_accel_t *accel = (vdpau_accel_t*)img->accel_data;
   if ( !seq->accel_vdpau )
     seq->accel_vdpau = accel;
@@ -947,6 +946,7 @@ static void decode_picture( vdpau_mpeg4_decoder_t *vd )
   img->bad_frame = 0;
   if ( seq->video_step > 900 ) /* some buggy streams */
     img->duration = seq->video_step;
+  accel->color_standard = seq->color_standard;
 
   if ( pic->vdp_infos.vop_coding_type < B_FRAME ) {
     if ( pic->vdp_infos.vop_coding_type == I_FRAME && !seq->backward_ref ) {
@@ -993,14 +993,14 @@ static void vdpau_mpeg4_decode_data (video_decoder_t *this_gen, buf_element_t *b
     seq->cur_pts = buf->pts;
 
   int size = seq->bufpos+buf->size;
-  if ( seq->bufsize < (unsigned int)size ) {
+  if ( seq->bufsize < size ) {
     seq->bufsize = size+1024;
     seq->buf = realloc( seq->buf, seq->bufsize );
   }
   xine_fast_memcpy( seq->buf+seq->bufpos, buf->content, buf->size );
   seq->bufpos += buf->size;
 
-  while ( seq->bufseek <= (int)(seq->bufpos)-4 ) {
+  while ( seq->bufseek <= seq->bufpos-4 ) {
     uint8_t *buffer = seq->buf+seq->bufseek;
     if ( buffer[0]==0 && buffer[1]==0 && buffer[2]==1 ) {
       if ( seq->start<0 ) {
@@ -1029,7 +1029,6 @@ static void vdpau_mpeg4_decode_data (video_decoder_t *this_gen, buf_element_t *b
 static void vdpau_mpeg4_flush (video_decoder_t *this_gen) {
 
   lprintf( "vdpau_mpeg4_flush\n" );
-  (void)this_gen;
 }
 
 /*
@@ -1062,12 +1061,8 @@ static void vdpau_mpeg4_dispose (video_decoder_t *this_gen) {
   lprintf( "vdpau_mpeg4_dispose\n" );
 
   if ( this->decoder!=VDP_INVALID_HANDLE && this->sequence.accel_vdpau ) {
-      if (this->sequence.accel_vdpau->lock)
-        this->sequence.accel_vdpau->lock (this->sequence.accel_vdpau->vo_frame);
       this->sequence.accel_vdpau->vdp_decoder_destroy( this->decoder );
       this->decoder = VDP_INVALID_HANDLE;
-      if (this->sequence.accel_vdpau->unlock)
-        this->sequence.accel_vdpau->unlock (this->sequence.accel_vdpau->vo_frame);
     }
 
   free_sequence( &this->sequence );
@@ -1088,41 +1083,25 @@ static video_decoder_t *open_plugin (video_decoder_class_t *class_gen, xine_stre
 
   lprintf( "open_plugin\n" );
 
-  (void)class_gen;
-
   /* the videoout must be vdpau-capable to support this decoder */
-  if ( !(stream->video_out->get_capabilities(stream->video_out) & VO_CAP_VDPAU_MPEG4) )
+  if ( !(stream->video_driver->get_capabilities(stream->video_driver) & VO_CAP_VDPAU_MPEG4) )
     return NULL;
 
   /* now check if vdpau has free decoder resource */
-  vo_frame_t *img = stream->video_out->get_frame( stream->video_out, 1920, 1080, 1, XINE_IMGFMT_VDPAU,
-                                                  VO_BOTH_FIELDS | VO_GET_FRAME_MAY_FAIL );
-  if (!img) {
-    return NULL;
-  }
+  vo_frame_t *img = stream->video_out->get_frame( stream->video_out, 1920, 1080, 1, XINE_IMGFMT_VDPAU, VO_BOTH_FIELDS );
   vdpau_accel_t *accel = (vdpau_accel_t*)img->accel_data;
   int runtime_nr = accel->vdp_runtime_nr;
   img->free(img);
   VdpDecoder decoder;
-  if (accel->lock)
-    accel->lock (accel->vo_frame);
   VdpStatus st = accel->vdp_decoder_create( accel->vdp_device, VDP_DECODER_PROFILE_MPEG4_PART2_ASP, 1920, 1080, 2, &decoder );
-  if (accel->unlock)
-    accel->unlock (accel->vo_frame);
   if ( st!=VDP_STATUS_OK ) {
     lprintf( "can't create vdpau decoder.\n" );
     return NULL;
   }
 
-  if (accel->lock)
-    accel->lock (accel->vo_frame);
   accel->vdp_decoder_destroy( decoder );
-  if (accel->unlock)
-    accel->unlock (accel->vo_frame);
 
   this = (vdpau_mpeg4_decoder_t *) calloc(1, sizeof(vdpau_mpeg4_decoder_t));
-  if (!this)
-    return NULL;
 
   this->video_decoder.decode_data         = vdpau_mpeg4_decode_data;
   this->video_decoder.flush               = vdpau_mpeg4_flush;
@@ -1131,6 +1110,7 @@ static video_decoder_t *open_plugin (video_decoder_class_t *class_gen, xine_stre
   this->video_decoder.dispose             = vdpau_mpeg4_dispose;
 
   this->stream                            = stream;
+  this->class                             = (vdpau_mpeg4_class_t *) class_gen;
 
   this->sequence.bufsize = 1024;
   this->sequence.buf = (uint8_t*)malloc(this->sequence.bufsize);
@@ -1161,19 +1141,53 @@ static video_decoder_t *open_plugin (video_decoder_class_t *class_gen, xine_stre
  * This function allocates a private video decoder class and initializes
  * the class's member functions.
  */
-void *mpeg4_init_plugin (xine_t *xine, const void *data) {
+static void *init_plugin (xine_t *xine, void *data) {
 
-  (void)xine;
-  (void)data;
+  vdpau_mpeg4_class_t *this;
 
-  static const video_decoder_class_t decode_video_vdpau_mpeg4_class = {
-    .open_plugin     = open_plugin,
-    .identifier      = "vdpau_mpeg4",
-    .description     =
-        N_("vdpau_mpeg4: mpeg4 part 2 decoder plugin using VDPAU hardware decoding.\n"
-           "Must be used along with video_out_vdpau."),
-    .dispose         = NULL,
-  };
+  this = (vdpau_mpeg4_class_t *) calloc(1, sizeof(vdpau_mpeg4_class_t));
 
-  return (void *)&decode_video_vdpau_mpeg4_class;
+  this->decoder_class.open_plugin     = open_plugin;
+  this->decoder_class.identifier      = "vdpau_mpeg4";
+  this->decoder_class.description     =
+	N_("vdpau_mpeg4: mpeg4 part 2 decoder plugin using VDPAU hardware decoding.\n"
+	   "Must be used along with video_out_vdpau.");
+  this->decoder_class.dispose         = default_video_decoder_class_dispose;
+
+  return this;
 }
+
+/*
+ * This is a list of all of the internal xine video buffer types that
+ * this decoder is able to handle. Check src/xine-engine/buffer.h for a
+ * list of valid buffer types (and add a new one if the one you need does
+ * not exist). Terminate the list with a 0.
+ */
+static const uint32_t video_types[] = {
+  BUF_VIDEO_MPEG4,
+  BUF_VIDEO_XVID,
+  BUF_VIDEO_DIVX5,
+  BUF_VIDEO_3IVX,
+  0
+};
+
+/*
+ * This data structure combines the list of supported xine buffer types and
+ * the priority that the plugin should be given with respect to other
+ * plugins that handle the same buffer type. A plugin with priority (n+1)
+ * will be used instead of a plugin with priority (n).
+ */
+static const decoder_info_t dec_info_video = {
+  video_types,         /* supported types */
+  0                    /* priority        */
+};
+
+/*
+ * The plugin catalog entry. This is the only information that this plugin
+ * will export to the public.
+ */
+const plugin_info_t xine_plugin_info[] EXPORTED = {
+  /* { type, API, "name", version, special_info, init_function } */
+  { PLUGIN_VIDEO_DECODER, 19, "vdpau_mpeg4", XINE_VERSION_CODE, &dec_info_video, init_plugin },
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
+};
